/*
 * Copyright (c) 2018 Fingerprint Cards AB <tech@fingerprints.com>
 *
 * All rights are reserved.
 * Proprietary and confidential.
 * Unauthorized copying of this file, via any medium is strictly prohibited.
 * Any use is subject to an appropriate license granted by Fingerprint Cards AB.
 *
 */

#include <stdint.h>

/**
 * @brief Module quality test (MQT)
 *        Perform FPC module quality test and calculate SNR value.
 *
 * @param[in]     image_data       Image data originating from acquire interface
 * @param[in]     image_data_size  Image data size
 * @param[out]    snr              The SNR result value calculated in test.
 *
 * Image used for the test should be captured with fpsensor capture mode
 * "CAPTURE_MODE_MQT"
 *
 * @return 0 on success, negative error code
 */
int32_t fputils_mqt(uint8_t *image_data, uint32_t image_data_size, float *snr);

/**
 * @brief FMI is the serialized format used for FPC image data. This function
 *        generates an in-memory FMI representation from the output data from.
 *
 *        - fp_sensor_acquire_image
 *        - fp_sensor_acquire_image_with_mode
 *
 * @param[in]     image_data       Image data originating from acquire interface
 * @param[in]     image_data_size  Image data size
 * @param[in,out] fmi_data         Allocated buffer for FMI representation. Pass
 *                                 fmi_data as NULL to retrieve memory requirements.
 *
 * Memory requirement for the fmi_data depends on capture type and number of supported
 * defect pixels.
 *
 * @return 0 on success, negative error code
 */
int32_t fputils_image_data_to_fmi(uint8_t *image_data,
                                  uint32_t image_data_size,
                                  uint8_t *fmi_data);


#define FPUTILS_NUM_IMAGE_BUFFERS (3)

typedef struct {
    uint8_t *data; /* start address of image buffer */
    uint32_t size; /* size of image buffer          */
} fputils_image_buffer_t;

/*
 * fputils_get_image_buffers - Get the address and size of the raw image(s)
 * within a raw buffer as returned by the acquire image function.
 *
 * A successful image acquire buffer may contain 1-3 raw images.
 *
 * @param[in]  image_data      pointer to image data as retrieved from fp_sensor_acquire_image
 * @param[in]  image_data_size the size of the image data
 * @param[out] image_buffers   array of FPUTILS_NUM_IMAGE_BUFFERS image buffers
 *
 * @return
 * - 0 on success
 * - negative value on error
 *
 * A valid image buffer is indicated by a size not equal to 0.
 */
int32_t fputils_get_image_buffers(
    uint8_t *image_data,
    uint32_t image_data_size,
    fputils_image_buffer_t image_buffers[FPUTILS_NUM_IMAGE_BUFFERS]);

